@@ -13,40 +13,30 @@ from mindsdb_native.libs.data_types.mindsdb_logger import log
 
 
 class DataSource:
-    def __init__(self, *args, **kwargs):
+    def __init__(self, df=None, query=None):
+        if type(self) is DataSource and df is None:
+            raise Exception('When you\'re instantiating DataSource, you must provide :param df:')
+
+        self._query = query
+
+        if df is not None:
+            self._internal_df = df
+            self._internal_col_map = self._make_colmap(df)
+        else:
+            self._internal_df = None
+            self._internal_col_map = None
+
         self.data_types = {}
         self.data_subtypes = {}
-        self._internal_df = None
-        self._internal_col_map = None
-        self.args = args
-        self.kwargs = kwargs
-
-        if 'is_sql' not in self.__dict__:
-            self.is_sql = False
-
-        # @TOOD Let's just make the query an "obligatory" first arg of all sql datasources
-        if self.is_sql:
-            # @TODO Also, even if we do the above, it might be wiser to set the `query` inside each separate datasource child ?
-            try:
-                self.query = self.kwargs['query']
-            except Exception as e:
-                self.query = self.args[0]
-
-        self._cleanup()
 
     def __len__(self):
         return len(self.df)
 
-    def _setup(self, df, **kwargs):
+    def _make_colmap(self, df):
         col_map = {}
-
         for col in df.columns:
             col_map[col] = col
-
-        return df, col_map
-
-    def _cleanup(self):
-        pass
+        return col_map
 
     def set_subtypes(self, data_subtypes):
         """
@@ -68,7 +58,7 @@ class DataSource:
     @property
     def df(self):
         if self._internal_df is None:
-            self._internal_df, self._internal_col_map = self._setup(*self.args, **self.kwargs)
+            self._internal_df, self._internal_col_map = self.query(self._query)
         return self._internal_df
 
     @df.setter
@@ -78,12 +68,7 @@ class DataSource:
     @property
     def _col_map(self):
         if self._internal_col_map is None:
-            # Probably more elegant without the `if` but python is dumb and can easily get itself into weird internal loops => core dumps if
-            if self.is_sql:
-                _, self._internal_col_map = self.filter(where=[], limit=1, get_col_map=True)
-            else:
-                self._internal_df, self._internal_col_map = self._setup(*self.args, **self.kwargs)
-
+            self._internal_df, self._internal_col_map = self.query(self._query)
         return self._internal_col_map
 
     @_col_map.setter
@@ -110,6 +95,26 @@ class DataSource:
 
         self._internal_df.drop(columns=columns_to_drop, inplace=True)
 
+    def query(self, q=None):
+        """
+        :param q: a query specific to type of datasource
+        Datasources must override this method to return pandas.DataFrame
+        based on :param q:
+        e.g. for MySqlDS :param q: must be a SQL query
+             for MongoDS :param q: must be a dictionary
+            
+        :return: tuple(pandas.DataFrame, dict)
+        """
+
+        # If it's not a subclass of DataSource, then dataframe was provided
+        # in the constructor and we just return it
+        if type(self) is DataSource:
+            return self._internal_df, self._internal_col_map
+
+        # If it is a subclass of DataSource, then this method must be overriden
+        else:
+            raise NotImplementedError('You must override DataSource.query')
+
     def _filter_df(self, raw_condition, df):
         """Convert filter conditions to a paticular
         DataFrame instance"""
@@ -131,10 +136,47 @@ class DataSource:
         return df
 
     def filter(self, where=None, limit=None, get_col_map=False):
-        """Convert SQL like filter requests to pandas DataFrame filtering"""
+        df = self.df
+        if where:
+            for cond in where:
+                df = self._filter_df(cond, df)
+        return df.head(limit) if limit else df
+
+    def __getstate__(self):
+        return self.__dict__
+
+    def __setstate__(self, d):
+        self.__dict__.update(d)
+
+    def __getattr__(self, attr):
+        """
+        Map all other functions to the DataFrame
+        """
         try:
-            assert self.is_sql
-            parsed_query = moz_sql_parser.parse(self.query)
+            return super().__getattribute__(attr)
+        except AttributeError:
+            return getattr(self.df, attr)
+
+    def __getitem__(self, key):
+        """
+        Map all other items to the DataFrame
+        """
+        return self.df.__getitem__(key)
+
+    def __setitem__(self, key, value):
+        """
+        Support item assignment, mapped to DataFrame
+        """
+        self.df.__setitem__(key, value)
+
+
+class SQLDataSource(DataSource):
+    def __init__(self, query):
+        super().__init__(query=query)
+
+    def filter(self, where=None, limit=None, get_col_map=False):
+        try:
+            parsed_query = moz_sql_parser.parse(self._query)
 
             for col, op, value in where or []:
                 past_where_clause = parsed_query.get('where', {})
@@ -143,9 +185,9 @@ class DataSource:
                 op_json = binary_ops.get(op, None)
                 if op_json is None:
                     log.warning(f"Operator: {op} not found in: QueryBuilder._OPERATORS\n Using it anyway.")
-                    op_json = op.lower()
+                    op_json = op
 
-                if op.lower() == 'like':
+                if op == 'like':
                     value = '%' + value.strip('%') + '%'
 
                 where_clause = {op_json: [col, value]}
@@ -159,54 +201,18 @@ class DataSource:
                 parsed_query['limit'] = limit
 
             query = moz_sql_parser.format(parsed_query)
-            query = query.replace('"',"'")
-            args = deepcopy(self.args)
-            kwargs = deepcopy(self.kwargs)
-
-            if 'query' in kwargs:
-                kwargs['query'] = query
-            else:
-                args[0] = query
+            query = query.replace('"', "'")
 
             if get_col_map:
-                return self._setup(*args, **kwargs)
+                return self.query(query)
             else:
-                return self._setup(*args, **kwargs)[0]
-        except Exception as e:
-            df = self.df
-            if where:
-                for cond in where:
-                    df = self._filter_df(cond, df)
-            return df.head(limit) if limit else df
+                return self.query(query)[0]
 
-    def __getstate__(self):
-        return self.__dict__
+        except Exception:
+            return super().filter(where=where, limit=limit, get_col_map=get_col_map)
 
-    def __setstate__(self, d):
-        self.__dict__.update(d)
-
-    def __getattr__(self, attr):
-        """
-        Map all other functions to the DataFrame
-        """
-        if attr == 'df':
-            return self.df
-        if attr == 'col_map':
-            return self.col_map
-
-        if attr.startswith('__') and attr.endswith('__'):
-            raise AttributeError
-        else:
-            return self.df.__getattr__(attr)
-
-    def __getitem__(self, key):
-        """
-        Map all other items to the DataFrame
-        """
-        return self.df.__getitem__(key)
-
-    def __setitem__(self, key, value):
-        """
-        Support item assignment, mapped to DataFrame
-        """
-        self.df.__setitem__(key, value)
+    @property
+    def _col_map(self):
+        if self._internal_col_map is None:
+            _, self._internal_col_map = self.filter(where=[], limit=1, get_col_map=True)
+        return self._internal_col_map
