@@ -5,17 +5,13 @@ from mindsdb_native.libs.constants.mindsdb import TRANSACTION_LEARN
 
 
 class DataCleaner(BaseModule):
-    def _get_useless_columns(self, df):
+    def _get_empty_columns(self, df):
         empty_columns = []
-        zero_information_columns = []
         for col_name in df.columns.values:
             if len(df[col_name].dropna()) < 1:
                 empty_columns.append(col_name)
                 self.log.warning(f'Column "{col_name}" is empty ! We\'ll go ahead and ignore it, please make sure you gave mindsdb the correct data.')
-            elif len(set(df[col_name])) == 1:
-                zero_information_columns.append(col_name)
-                self.log.warning(f'Column "{col_name}" is always equal to "{df[col_name].iloc[0]}" ! We\'ll go ahead and ignore it, please make sure you gave mindsdb the correct data.')
-        return empty_columns, zero_information_columns
+        return empty_columns
 
     def _remove_missing_targets(self, df):
         initial_len = len(df)
@@ -52,14 +48,14 @@ class DataCleaner(BaseModule):
             # That's why np.nan is used here instead of None
             df[col].replace(nulls, np.nan, inplace=True)
 
-        empty_columns, zero_information_columns = self._get_useless_columns(df)
+        empty_columns = self._get_empty_columns(df)
 
         self.transaction.lmd['empty_columns'] = empty_columns
-        self.transaction.lmd['zero_information_columns'] = zero_information_columns
-        self.transaction.lmd['columns_to_ignore'].extend(empty_columns)
 
-        self.transaction.lmd['columns_to_ignore'] = list(
-            set(self.transaction.lmd['zero_information_columns'] + self.transaction.lmd['columns_to_ignore']).difference(
+        self.transaction.lmd['columns_to_ignore'].extend(
+            set(empty_columns).difference(
+                self.transaction.lmd['predict_columns']
+            ).difference(
                 self.transaction.lmd['force_column_usage']
             )
         )
