@@ -3,7 +3,7 @@ from mindsdb_native.libs.constants.mindsdb import *
 from mindsdb_native.libs.phases.base_module import BaseModule
 from mindsdb_native.libs.helpers.general_helpers import evaluate_accuracy
 from mindsdb_native.libs.helpers.conformal_helpers import ConformalClassifierAdapter, ConformalRegressorAdapter, clean_df
-from mindsdb_native.libs.helpers.probabilistic_validator import ProbabilisticValidator
+from mindsdb_native.libs.helpers.accuracy_stats import AccStats
 from mindsdb_native.libs.data_types.mindsdb_logger import log
 from sklearn.metrics import balanced_accuracy_score, r2_score
 
@@ -20,7 +20,7 @@ class ModelAnalyzer(BaseModule):
     def run(self):
         np.seterr(divide='warn', invalid='warn')
         """
-        # Runs the model on the validation set in order to fit a probabilistic model that will evaluate the accuracy of future predictions
+        # Runs the model on the validation set in order to evaluate the accuracy and confidence of future predictions
         """
 
         validation_df = self.transaction.input_data.validation_df
@@ -105,13 +105,12 @@ class ModelAnalyzer(BaseModule):
             # normalize from 0 to 10
             self.transaction.lmd['column_importances'][col] = 10 * max(0, accuracy_increase)
 
-        # Run Probabilistic Validator
+        # Get accuracy stats
         overall_accuracy_arr = []
         self.transaction.lmd['accuracy_histogram'] = {}
         self.transaction.lmd['confusion_matrices'] = {}
         self.transaction.lmd['accuracy_samples'] = {}
-        self.transaction.hmd['probabilistic_validators'] = {}
-
+        self.transaction.hmd['acc_stats'] = {}
 
         self.transaction.lmd['train_data_accuracy'] = {}
         self.transaction.lmd['test_data_accuracy'] = {}
@@ -159,17 +158,17 @@ class ModelAnalyzer(BaseModule):
             )
 
         for col in output_columns:
-            pval = ProbabilisticValidator(col_stats=self.transaction.lmd['stats_v2'][col], col_name=col, input_columns=input_columns)
+            acc_stats = AccStats(col_stats=self.transaction.lmd['stats_v2'][col], col_name=col, input_columns=input_columns)
             predictions_arr = [normal_predictions_test] + [x for x in empty_input_predictions_test.values()]
 
-            pval.fit(test_df, predictions_arr, [[ignored_column] for ignored_column in empty_input_predictions_test])
-            overall_accuracy, accuracy_histogram, cm, accuracy_samples = pval.get_accuracy_stats()
+            acc_stats.fit(test_df, predictions_arr, [[ignored_column] for ignored_column in empty_input_predictions_test])
+            overall_accuracy, accuracy_histogram, cm, accuracy_samples = acc_stats.get_accuracy_stats()
             overall_accuracy_arr.append(overall_accuracy)
 
             self.transaction.lmd['accuracy_histogram'][col] = accuracy_histogram
             self.transaction.lmd['confusion_matrices'][col] = cm
             self.transaction.lmd['accuracy_samples'][col] = accuracy_samples
-            self.transaction.hmd['probabilistic_validators'][col] = pickle_obj(pval)
+            self.transaction.hmd['acc_stats'][col] = pickle_obj(acc_stats)
 
         self.transaction.lmd['validation_set_accuracy'] = sum(overall_accuracy_arr)/len(overall_accuracy_arr)
 
